
;       equates.inc - psx equates file

;       basic equates...
false           equ     0
true            equ     1
error           equ     -1
kbyte           equ     1024
mbyte           equ     1024*kbyte

;       rom & ram addresses & sizes
external_rom    equ     $1f000000       ; external cartridge port (parallel port)
rom             equ     $bfc00000       ; psx rom address
ram             equ     $80000000       ; psx main ram address
ram_length      equ     2*mbyte         ; size of normal psx memory
os_space        equ     64*kbyte        ; first 64k given to operating system
user_ram        equ     ram+os_space    ; address of first place programs can go        

;       hardware...
hardware        equ     $1f800000       ; base address of hardware
scratchpad      equ     hardware+$0000  ; extra fast scratchpad memory
scratchpad_len  equ     1*kbyte         ; size of scratchpad memory

spu_delay       equ     hardware+$1014  ; sound processor delay?
dv5_delay       equ     hardware+$1018  ; ???
com_delay       equ     hardware+$1020  ; common delay?

memcard         equ     hardware+$1040  ; memory card base address
memcard_data    equ     memcard+$0      ; memory card serial data
memcard_status  equ     memcard+$4      ; memory card serial status
memcard_ctrl    equ     memcard+$a      ; memory card serial control
memcard_baud    equ     memcard+$e      ; memory card serial baud rate

serial          equ     hardware+$1050  ; serial port base address
serial_data     equ     serial+$0       ; serial port data
serial_status   equ     serial+$4       ; serial port status
serial_ctrl     equ     serial+$a       ; serial port control
serial_baud     equ     serial+$e       ; serial port baud rate

ram_size        equ     hardware+$1060  ; ram size (or type?), usually contains $b88

;       important interrupt information:
;               bits correspond to both interrupt_reg & interrupt_mask
;                       bit 0:vertical blank interrupt
;                       bit 4:root 0 interrupt
;                       bit 5:root 1 interrupt
;                       bit 6:root 2 interrupt
interrupt       equ     hardware+$1070  ; interrupt base address
interrupt_reg   equ     interrupt+$0    ; interrupt register
interrupt_mask  equ     interrupt+$4    ; interrupt mask

dma0            equ     hardware+$1080  ; dma 0 - mdec in
dma0_mem        equ     dma0+$0         ; dma 0 memory address
dma0_size       equ     dma0+$4         ; dma 0 size
dma0_ctrl       equ     dma0+$8         ; dma 0 control

dma1            equ     hardware+$1090  ; dma 1 - mdec out
dma1_mem        equ     dma1+$0         ; dma 1 memory address
dma1_size       equ     dma1+$4         ; dma 1 size
dma1_ctrl       equ     dma1+$8         ; dma 1 control

dma2            equ     hardware+$10a0  ; dma 2- gpu
dma2_mem        equ     dma2+$0         ; dma 2 memory address
dma2_size       equ     dma2+$4         ; dma 2 size
dma2_ctrl       equ     dma2+$8         ; dma 2 control

dma3            equ     hardware+$10b0  ; dma 3 - cdrom
dma3_mem        equ     dma3+$0         ; dma 3 memory address
dma3_size       equ     dma3+$4         ; dma 3 size
dma3_ctrl       equ     dma3+$8         ; dma 3 control

;       important spu dma information:
;               pack samples:
;                       byte 0:hi nibble=predictor number,lo nibble=shift factor
;                       byte 1:flag
;                               $02=something to do with repeat!
;                               $03=sample end, restart at repeat point
;                               $04=set repeat point
;                               $06=repeat start
;                               $07=sample end
;                       bytes 2..15:packed sample data (28 samples at a time?)
;               transfer packed info:
;                       set source address with spu_dma_mem
;                       set destination/8 with spu_addr
;                       size/64 into bits 16..31 of spu_dma_size
;                       then set bit 24 of spu_dma_ctrl (cleared after transfer) 
dma4            equ     hardware+$10c0  ; dma 4 - spu
dma4_mem        equ     dma4+$0         ; dma 4 memory address
dma4_size       equ     dma4+$4         ; dma 4 size
dma4_ctrl       equ     dma4+$8         ; dma 4 control
spu_dma_mem     equ     dma4_mem
spu_dma_size    equ     dma4_size
spu_dma_ctrl    equ     dma4_ctrl

dma5            equ     hardware+$10d0  ; dma 5 - ???
dma5_mem        equ     dma5+$0         ; dma 5 memory address
dma5_size       equ     dma5+$4         ; dma 5 size
dma5_ctrl       equ     dma5+$8         ; dma 5 control

dma6            equ     hardware+$10e0  ; dma 6 - memory
dma6_mem        equ     dma6+$0         ; dma 6 memory address
dma6_size       equ     dma6+$4         ; dma 6 size
dma6_ctrl       equ     dma6+$8         ; dma 6 control

dma_pcr         equ     hardware+$10f0  ; dma control register
dma_icr         equ     hardware+$10f4  ; dma control register

;       important root counter (timer) information:
;               all root counters based on 33.872mhz clock frequency
;               rootX_count=current counting status (read)
;               rootX_mode:
;                       bit 0:0=counting, 1=not counting
;                       bit 3:0=timer loops?, 1=timer stops
;                       bit 4:interrupt enable
;                       bit 6:interrupt enable
;                       bit 8:???
root0           equ     hardware+$1100  ; root counter 0 base address
root0_count     equ     root0+$0        ; current count
root0_mode      equ     root0+$4        ; mode
root0_target    equ     root0+$8        ; target count

root1           equ     hardware+$1110  ; root counter 0 base address
root1_count     equ     root1+$0        ; current count
root1_mode      equ     root1+$4        ; mode
root1_target    equ     root1+$8        ; target count

root2           equ     hardware+$1120  ; root counter 0 base address
root2_count     equ     root2+$0        ; current count
root2_mode      equ     root2+$4        ; mode
root2_target    equ     root2+$8        ; target count

cdrom           equ     hardware+$1800  ; cdrom base address
cdrom_reg0      equ     cdrom+0
cdrom_reg1      equ     cdrom+1
cdrom_reg2      equ     cdrom+2
cdrom_reg3      equ     cdrom+3

gpu0            equ     hardware+$1810  ; gpu register 0
gpu1            equ     hardware+$1814  ; gpu register 1

mdec0           equ     hardware+$1820  ; mdec register 0
mdec1           equ     hardware+$1824  ; mdec register 1

spu             equ     hardware+$1c00  ; spu base address
spu_voice       equ     spu+$000        ; spu voice base address (24 voices of 16 bytes each from here)
;       offsets for the control of each voice
volume_l        equ     $0              ; left volume (bit 14=sign, 0..13=volume)
volume_r        equ     $2              ; right volume (bit 14=sign, 0..13=volume)
pitch           equ     $4              ; pitch control
wave            equ     $6              ; wave pattern address (address/8)
fx_adsr         equ     $8              ; attack rate (bits 8..15) + delay rate (bits 4..7) + sustain level (bits 0..3)
fx_adsr2        equ     $a              ; sustain rate (bits 6..15) + release rate (bits 0..5)
fx_volume       equ     $c              ; adsr volume (0-$7fff, usually set to $7fff)
repeat          equ     $e              ; current repeat address/8

spu_volume_l    equ     spu+$180        ; spu main volume left
spu_volume_r    equ     spu+$182        ; spu main volume right
spu_reverb_l    equ     spu+$184        ; spu reverb depth left
spu_reverb_r    equ     spu+$186        ; spu reverb depth right
spu_start_0     equ     spu+$188        ; spu voices 0-15 on
spu_start_1     equ     spu+$18a        ; spu voices 16-23 on
spu_stop_0      equ     spu+$18c        ; spu voices 0-15 off
spu_stop_1      equ     spu+$18e        ; spu voices 16-23 off
spu_fm_mode_0   equ     spu+$190        ; spu voices 0-15 fm mode
spu_fm_mode_1   equ     spu+$192        ; spu voices 16-23 fm mode
spu_noise_0     equ     spu+$194        ; spu voices 0-15 use as noise generator
spu_noise_1     equ     spu+$196        ; spu voices 16-23 use as noise generator
spu_reverb_0    equ     spu+$198        ; spu voices 0-15 reverb mode
spu_reverb_1    equ     spu+$19a        ; spu voices 16-23 reverb mode
spu_active_0    equ     spu+$19c        ; spu voices 0-15 read active status
spu_active_1    equ     spu+$19e        ; spu voices 15-23 read active status

spu_addr        equ     spu+$1a6        ; spu address to transfer to/from

;       important spu_ctrl0 information:
;               bit 0:cd mix
;               bit 3:cd reverb
;               bit 4:transfer direction
;               bit 5:dma transfer
;               bit 7:reverb on
;               bits 8..13:noise frequency
;               bit 14:mute
;               bit 15:spu on 
spu_ctrl0       equ     spu+$1aa        ; spu control 0
spu_ctrl1       equ     spu+$1ac        ; spu control 1
spu_status      equ     spu+$1ae        ; spu status (bit 10)
spu_cd_volume_l equ     spu+$1b0        ; spu cd main volume left
spu_cd_volume_r equ     spu+$1b2        ; spu cd main volume right
spu_reverb_data equ     spu+$1c0        ; spu reverb configuration data to spu+$1ff
spu_factor_l    equ     spu+$1fc        ; ???
spu_factor_r    equ     spu+$1fe        ; ???
  
int_2000        equ     hardware+$2030  ; ???
dip_switches    equ     hardware+$2040  ; dip switches on developement machines?

;       gpu equates...
clut4           equ     0               ; tpage clut equates
clut8           equ     1
direct16        equ     3

trans0          equ     0               ; tpage transparency equates
trans1          equ     1
trans2          equ     2
trans3          equ     3

endgpu          equ     -1              ; end of gpu list

;       gte equates...
;               data registers:
vxy0            equ     0               ; vector #0 (x/y)
vz0             equ     1               ; vector #0 (z)
vxy1            equ     2               ; vector #1 (x/y)
vz1             equ     3               ; vector #1 (z)
vxy2            equ     4               ; vector #2 (x/y)
vz2             equ     5               ; vector #2 (z)
rgb             equ     6               ; colour data + gte instruction
otz             equ     7               ; z component average value
ir0             equ     8               ; intermediate value #0
ir1             equ     9               ; intermediate value #1
ir2             equ     10              ; intermediate value #2
ir3             equ     11              ; intermediate value #3
sxy0            equ     12              ; calculation result record (xy)
sxy1            equ     13              ; calculation result record (xy)
sxy2            equ     14              ; calculation result record (xy)
sxyp            equ     15              ; calculation result setting register
sz0             equ     16              ; calculation result record (z)
sz1             equ     17              ; calculation result record (z)
sz2             equ     18              ; calculation result record (z)
sz3             equ     19              ; calculation result record (z)
rgb0            equ     20              ; calculation result record (colour data)
rgb1            equ     21              ; calculation result record (colour data)
rgb2            equ     22              ; calculation result record (colour data)
res1            equ     23              ; reserved by system (access prohibited!!!)
mac0            equ     24              ; sum of products #0
mac1            equ     25              ; sum of products #1
mac2            equ     26              ; sum of products #2
mac3            equ     27              ; sum of products #3
irgb            equ     28              ; colour data input register
orgb            equ     29              ; colour data output register
lzcs            equ     30              ; leading zero/one count source data
lzcr            equ     31              ; leading zero/one count processing result
;               control registers:
r11r12          equ     0               ; rotation matrix
r13r21          equ     1               ; rotation matrix
r22r23          equ     2               ; rotation matrix
r31r32          equ     3               ; rotation matrix
r33             equ     4               ; rotation matrix
trx             equ     5               ; translation vector (x)
try             equ     6               ; translation vector (y)
trz             equ     7               ; translation vector (z)
l11l12          equ     8               ; light source direction vector x 3
l13l21          equ     9               ; light source direction vector x 3
l22l23          equ     10              ; light source direction vector x 3
l31l32          equ     11              ; light source direction vector x 3
l33             equ     12              ; light source direction vector x 3
rbk             equ     13              ; peripheral colour (background colour) (r)
gbk             equ     14              ; peripheral colour (background colour) (g)
bbk             equ     15              ; peripheral colour (background colour) (b)
lr1lr2          equ     16              ; light source colour x 3
lr3lg1          equ     17              ; light source colour x 3
lg2lg3          equ     18              ; light source colour x 3
lb1lb2          equ     19              ; light source colour x 3
lb3             equ     20              ; light source colour x 3
rfc             equ     21              ; far colour (r)
gfc             equ     22              ; far colour (g)
bfc             equ     23              ; far colour (b)
ofx             equ     24              ; screen offset (x)
ofy             equ     25              ; screen offset (y)
h               equ     26              ; screen position
dqa             equ     27              ; depth parameter a (coefficient)
dqb             equ     28              ; depth parameter b (offset)
zsf3            equ     29              ; z averaging scale factor
zsf4            equ     30              ; z averaging scale factor
flag            equ     31              ; flag

;       system call equates...
;               general (used by parameters to system calls):
FREAD           equ     $0001           ; readable
FWRITE          equ     $0002           ; writable
FNBLOCK         equ     $0004           ; non-blocking reads
FRLOCK          equ     $0010           ; read locked (non-shared)
FWLOCK          equ     $0020           ; write locked (non-shared)
FAPPEND         equ     $0100           ; append on each write
FCREAT          equ     $0200           ; create if non-existant
FTRUNC          equ     $0400           ; truncate to zero length
FSCAN           equ     $1000           ; scan type
FRCOM           equ     $2000           ; remote command entry
FNBUF           equ     $4000           ; no ring buf. & console interrupt
FASYNC          equ     $8000           ; asyncronous i/o
O_RDONLY        equ     FREAD
O_WRONLY        equ     FWRITE
O_RDWR          equ     FREAD!FWRITE
O_CREAT         equ     FCREAT
O_NOBUF         equ     FNBUF
O_NOBLOCK       equ     FNBLOCK
O_NOWAIT        equ     FASYNC
SEEK_SET        equ     0               ; seek to start+offset
SEEK_CUR        equ     1               ; seek to current+offset
SEEK_END        equ     2               ; seek to end or end+offset?

;               a0 calls:
open_2          equ     $00             ; fd=*filename,flag             opens a file
lseek_2         equ     $01             ; offset=fd,offset,flag         moves a file pointer
read_2          equ     $02             ; numbytes=fd,*address,numbytes reads data from a file
write_2         equ     $03             ; numbytes=fd,*address,numbytes writes data to a file
close_2         equ     $04             ; fd=fd                         closes a fiel
ioctl_2         equ     $05             ; bool=fd,command,arguement     controls devices
exit_2          equ     $06             ; error                         exits the program & displays an error screen
sys_b0_39       equ     $07             ;                               ???
getc_2          equ     $08             ; char=stream                   gets a character
putc_2          equ     $09             ; char=char,stream              puts a character
todigit         equ     $0a             ;                               ???
atof            equ     $0b             ; hi,lo=*string                 converts string to floating point
strtoul         equ     $0c             ; ???
strtol          equ     $0d             ; ???
abs             equ     $0e             ; ???
labs            equ     $0f             ; ???
atoi            equ     $10             ; ???
atol            equ     $11             ; ???
atob            equ     $12             ; ???
setjmp          equ     $13             ; ???
longjmp         equ     $14             ; ???
strcat          equ     $15             ; ???
strncat         equ     $16             ; ???
strcmp_2        equ     $17             ; ???
strncmp         equ     $18             ; ???
strcpy          equ     $19             ; ???
strncpy         equ     $1a             ; ???
strlen_2        equ     $1b             ; ???
index           equ     $1c             ; ???
rindex          equ     $1d             ; ???
strchr          equ     $1e             ; ???
strrchr         equ     $1f             ; ???
strpbrk         equ     $20             ; ???
strspn          equ     $21             ; ???
strcspn         equ     $22             ; ???
strtok          equ     $23             ; ???
strstr          equ     $24             ; ???
toupper         equ     $25             ; ???
tolower         equ     $26             ; ???
bcopy           equ     $27             ; ???
bzero           equ     $28             ; ???
bcmp            equ     $29             ; ???
memcpy          equ     $2a             ; ???
memset          equ     $2b             ; ???
memmove         equ     $2c             ; ???
memcmp          equ     $2d             ; ???
memchr          equ     $2e             ; ???
rand            equ     $2f             ; ???
srand           equ     $30             ; ???
qsort           equ     $31             ; ???
strtod          equ     $32             ; ???
malloc          equ     $33             ; ???
free            equ     $34             ; ???
lsearch         equ     $35             ; ???
bsearch         equ     $36             ; ???
calloc          equ     $37             ; ???
realloc         equ     $38             ; ???
InitHeap        equ     $39             ; ???
_exit           equ     $3a             ; ???
getchar_2       equ     $3b             ; ???
putchar_2       equ     $3c             ; ???
gets_2          equ     $3d             ; ???
puts_2          equ     $3e             ; ???
printf          equ     $3f             ; ???
LoadTest        equ     $41             ; ???
Load            equ     $42             ; ???
Exec            equ     $43             ; ???
FlushCache      equ     $44             ; ???
InstallInterruptHandler equ $45         ; ???
GPU_dw          equ     $46             ; ???
SetGPUStatus    equ     $48             ; ???
GPU_cw          equ     $49             ; ???
GPU_cwb         equ     $4a             ; ???
GetGPUStatus    equ     $4d             ; ???
GPU_sync        equ     error           ; ???
LoadExec        equ     $51             ; ???
GetSysSp        equ     $52             ; ???
_96_init        equ     $54             ; ???
_bu_init        equ     $55             ; ???
_96_remove      equ     $56             ; ???
dev_tty_init    equ     $5b             ; ???
dev_tty_open    equ     $5c             ; ???
dev_tty_ioctl   equ     $5e             ; ???
dev_cd_open     equ     $5f             ; ???
dev_cd_read     equ     $60             ; ???
dev_cd_close    equ     $61             ; ???
dev_cd_firstfile equ    $62             ; ???
dev_cd_nextfile equ     $63             ; ???
dev_cd_chdir    equ     $64             ; ???
dev_card_open   equ     $65             ; ???
dev_card_read   equ     $66             ; ???
dev_card_write  equ     $67             ; ???
dev_card_close  equ     $68             ; ???
dev_card_firstfile equ  $69             ; ???
dev_card_nextfile equ   $6a             ; ???
dev_card_erase  equ     $6b             ; ???
dev_card_undelete equ   $6c             ; ???
dev_card_format equ     $6d             ; ???
dev_card_rename equ     $6e             ; ???
_bu_init_2      equ     $70             ; ???
_96_init_2      equ     $71             ; ???
_96_remove_2    equ     $72             ; ???
_96_CdSeekL     equ     $78             ; ???
_96_CdGetStatus equ     $7c             ; ???
_96_CdRead      equ     $7e             ; ???
_96_CdStop      equ     $85             ; ???
AddCDROMDevice  equ     $96             ; ???
AddMemCardDevice equ    $97             ; ???
DisableKernelIORedirection equ $98      ; ???
EnableKernelIORedirection equ $99       ; ???
GetConf         equ     $9c             ; ???
GetConf_2       equ     $9d             ; ???
SetMem          equ     $9f             ; ???
_boot           equ     $a0             ; ???
SystemError_2   equ     $a1             ; ???
EnqueueCdIntr   equ     $a2             ; ???
DequeueCdIntr   equ     $a3             ; ???
ReadSector      equ     $a5             ; ???
get_cd_status   equ     $a6             ; ???
bufs_cb_0       equ     $a7             ; ???
bufs_cb_1       equ     $a8             ; ???
bufs_cb_2       equ     $a9             ; ???
bufs_cb_3       equ     $aa             ; ???
_card_info      equ     $ab             ; ???
_card_load      equ     $ac             ; ???
_card_auto      equ     $ad             ; ???
bufs_cb_4       equ     $ae             ; ???
do_a_long_jmp   equ     $b2             ; ???
GetKernel       equ     $b4             ; ???
;               bo calls:
Sysmalloc       equ     $00             ; ???
DeliverEvent    equ     $07             ; ???
OpenEvent       equ     $08             ; ???
CloseEvent      equ     $09             ; ???
WaitEvent       equ     $0a             ; ???
TestEvent       equ     $0b             ; ???
EnableEvent     equ     $0c             ; ???
DisableEvent    equ     $0d             ; ???
OpenTh          equ     $0e             ; ???
CloseTh         equ     $0f             ; ???
ChangeTh        equ     $10             ; ???
InitPAD         equ     $12             ; ???
StartPAD        equ     $13             ; ???
StopPAD         equ     $14             ; ???
PAD_init        equ     $15             ; ???
PAD_dr          equ     $16             ; ???
ReturnFromException equ $17             ; ???
ResetEntryInt   equ     $18             ; ???
HookEntryInt    equ     $19             ; ???
UnDeliverEvent  equ     $20             ; ???
open            equ     $32             ; ???
lseek           equ     $33             ; ???
read            equ     $34             ; ???
write           equ     $35             ; ???
close           equ     $36             ; ???
ioctl           equ     $37             ; ???
exit            equ     $38             ; ???
getc            equ     $3a             ; ???
putc            equ     $3b             ; ???
getchar         equ     $3c             ; ???
putchar         equ     $3d             ; ???
gets            equ     $3e             ; ???
puts            equ     $3f             ; ???
cd              equ     $40             ; ???
format          equ     $41             ; ???
firstfile       equ     $42             ; ???
nextfile        equ     $43             ; ???
rename          equ     $44             ; ???
delete          equ     $45             ; ???
undelete        equ     $46             ; ???
AddDevice       equ     $47             ; ???
RemoveDevice    equ     $48             ; ???
PrintInstalledDevices equ $49           ; ???
InitCARD        equ     $4a             ; ???
StartCARD       equ     $4b             ; ???
StopCARD        equ     $4c             ; ???
_card_write     equ     $4e             ; ???
_card_read      equ     $4f             ; ???
_new_card       equ     $50             ; ???
Krom2RawAdd     equ     $51             ; ???
_get_errno      equ     $54             ; ???
_get_error      equ     $55             ; ???
GetC0Table      equ     $56             ; ???
GetB0Table      equ     $57             ; ???
_card_chan      equ     $58             ; ???
ChangeClearPad  equ     $5b             ; ???
_card_status    equ     $5c             ; ???
_card_wait      equ     $5d             ; ???
;               co calls:
InitRCnt        equ     $00             ; ???
InitException   equ     $01             ; ???
SysEnqIntRP     equ     $02             ; ???
SysDeqIntRP     equ     $03             ; ???
get_free_EvCB_slot equ  $04             ; ???
get_free_TCB_slot equ   $05             ; ???
ExceptionHandler equ    $06             ; ???
InstallExceptionHandlers equ $07        ; ???
SysInitMemory   equ     $08             ; ???
SysInitKMem     equ     $09             ; ???
ChangeClearRCnt equ     $0a             ; ???
SystemError     equ     $0b             ; ???
InitDefInt      equ     $0c             ; ???
InstallDevices  equ     $12             ; ???
FlushStdInOutPut equ    $13             ; ???
_cdevinput      equ     $15             ; ???
_cdevscan       equ     $16             ; ???
_circgetc       equ     $17             ; ???
_circputc       equ     $18             ; ???
ioabort         equ     $19             ; ???
KernelRedirect  equ     $1b             ; ???
PatchA0Table    equ     $1c             ; ???
;               special system calls:
Exception       equ     0       ; causes an interrupt & stores the current context in the execute tcb
EnterCriticalSection equ 1      ; stops interrupts & enters a critical section
ExitCriticalSection equ 2       ; enables interrupts & exits the critical section

